pub enum State {
Data,
Rcdata,
Rawtext,
ScriptData,
Plaintext,
Cdata,
}Expand description
A tokenizer state selected by the caller or a tree builder.
Variants
Data
Ordinary HTML content.
Rcdata
Text with character references, as in title and textarea.
Rawtext
Text without character references, as in style.
ScriptData
Script text, including HTML comment escapes.
Plaintext
Text through the end of the input.
Cdata
CDATA content; ]]> resumes the data state.